@@ -3,49 +3,43 @@ if [ -x /usr/bin/update-desktop-database ]; then
   /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
 fi
 
-( cd usr/lib ; rm -rf libkompareinterface.so.4 )
-( cd usr/lib ; ln -sf libkompareinterface.so.4.4.0 libkompareinterface.so.4 )
-( cd usr/lib ; rm -rf libkateinterfaces.so )
-( cd usr/lib ; ln -sf libkateinterfaces.so.4 libkateinterfaces.so )
-( cd usr/lib ; rm -rf libantlr.so.4 )
-( cd usr/lib ; ln -sf libantlr.so.4.4.0 libantlr.so.4 )
-( cd usr/lib ; rm -rf libkomparediff2.so.4 )
-( cd usr/lib ; ln -sf libkomparediff2.so.4.4.0 libkomparediff2.so.4 )
-( cd usr/lib ; rm -rf libkompareinterface.so )
-( cd usr/lib ; ln -sf libkompareinterface.so.4 libkompareinterface.so )
-( cd usr/lib ; rm -rf libktrace.so )
-( cd usr/lib ; ln -sf libktrace.so.4 libktrace.so )
-( cd usr/lib ; rm -rf libkateinterfaces.so.4 )
-( cd usr/lib ; ln -sf libkateinterfaces.so.4.4.0 libkateinterfaces.so.4 )
-( cd usr/lib ; rm -rf libktexteditor_codesnippets_core.so.0 )
-( cd usr/lib ; ln -sf libktexteditor_codesnippets_core.so.0.0.1 libktexteditor_codesnippets_core.so.0 )
-( cd usr/lib ; rm -rf libkomparediff2.so )
-( cd usr/lib ; ln -sf libkomparediff2.so.4 libkomparediff2.so )
-( cd usr/lib ; rm -rf libkomparedialogpages.so )
-( cd usr/lib ; ln -sf libkomparedialogpages.so.4 libkomparedialogpages.so )
-( cd usr/lib ; rm -rf libktrace.so.4 )
-( cd usr/lib ; ln -sf libktrace.so.4.4.0 libktrace.so.4 )
-( cd usr/lib ; rm -rf libktexteditor_codesnippets_core.so )
-( cd usr/lib ; ln -sf libktexteditor_codesnippets_core.so.0 libktexteditor_codesnippets_core.so )
-( cd usr/lib ; rm -rf libkomparedialogpages.so.4 )
-( cd usr/lib ; ln -sf libkomparedialogpages.so.4.4.0 libkomparedialogpages.so.4 )
-( cd usr/lib ; rm -rf libantlr.so )
-( cd usr/lib ; ln -sf libantlr.so.4 libantlr.so )
-( cd usr/share/doc/HTML/en/kbugbuster ; rm -rf common )
-( cd usr/share/doc/HTML/en/kbugbuster ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kompare ; rm -rf common )
-( cd usr/share/doc/HTML/en/kompare ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/umbrello ; rm -rf common )
 ( cd usr/share/doc/HTML/en/umbrello ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/cervisia ; rm -rf common )
-( cd usr/share/doc/HTML/en/cervisia ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kdesvn-build ; rm -rf common )
-( cd usr/share/doc/HTML/en/kdesvn-build ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/lokalize ; rm -rf common )
-( cd usr/share/doc/HTML/en/lokalize ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kcachegrind ; rm -rf common )
-( cd usr/share/doc/HTML/en/kcachegrind ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/kate ; rm -rf common )
 ( cd usr/share/doc/HTML/en/kate ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/kapptemplate ; rm -rf common )
 ( cd usr/share/doc/HTML/en/kapptemplate ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kompare ; rm -rf common )
+( cd usr/share/doc/HTML/en/kompare ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kdesrc-build ; rm -rf common )
+( cd usr/share/doc/HTML/en/kdesrc-build ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/lokalize ; rm -rf common )
+( cd usr/share/doc/HTML/en/lokalize ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/cervisia ; rm -rf common )
+( cd usr/share/doc/HTML/en/cervisia ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kcachegrind ; rm -rf common )
+( cd usr/share/doc/HTML/en/kcachegrind ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/lib ; rm -rf libkompareinterface.so.4 )
+( cd usr/lib ; ln -sf libkompareinterface.so.4.5.0 libkompareinterface.so.4 )
+( cd usr/lib ; rm -rf libkateinterfaces.so )
+( cd usr/lib ; ln -sf libkateinterfaces.so.4 libkateinterfaces.so )
+( cd usr/lib ; rm -rf libkateinterfaces.so.4 )
+( cd usr/lib ; ln -sf libkateinterfaces.so.4.5.0 libkateinterfaces.so.4 )
+( cd usr/lib ; rm -rf libkomparedialogpages.so.4 )
+( cd usr/lib ; ln -sf libkomparedialogpages.so.4.5.0 libkomparedialogpages.so.4 )
+( cd usr/lib ; rm -rf libkomparediff2.so )
+( cd usr/lib ; ln -sf libkomparediff2.so.4 libkomparediff2.so )
+( cd usr/lib ; rm -rf libkompareinterface.so )
+( cd usr/lib ; ln -sf libkompareinterface.so.4 libkompareinterface.so )
+( cd usr/lib ; rm -rf libktexteditor_codesnippets_core.so.0 )
+( cd usr/lib ; ln -sf libktexteditor_codesnippets_core.so.0.0.1 libktexteditor_codesnippets_core.so.0 )
+( cd usr/lib ; rm -rf libktrace.so.4 )
+( cd usr/lib ; ln -sf libktrace.so.4.5.0 libktrace.so.4 )
+( cd usr/lib ; rm -rf libktrace.so )
+( cd usr/lib ; ln -sf libktrace.so.4 libktrace.so )
+( cd usr/lib ; rm -rf libkomparediff2.so.4 )
+( cd usr/lib ; ln -sf libkomparediff2.so.4.5.0 libkomparediff2.so.4 )
+( cd usr/lib ; rm -rf libkomparedialogpages.so )
+( cd usr/lib ; ln -sf libkomparedialogpages.so.4 libkomparedialogpages.so )
+( cd usr/lib ; rm -rf libktexteditor_codesnippets_core.so )
+( cd usr/lib ; ln -sf libktexteditor_codesnippets_core.so.0 libktexteditor_codesnippets_core.so )
